==> codedeploy-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for an EC2/on-premise Deployment Group.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:25:49.613Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codedeploy.$Module.class, fqn = "@aws-cdk/aws-codedeploy.ServerDeploymentConfig")
public class ServerDeploymentConfig extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig {
    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        HALF_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "HALF_AT_A_TIME", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        ONE_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ONE_AT_A_TIME", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ServerDeploymentConfig(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a custom Deployment Configuration for an EC2/on-premise Deployment Group defined either outside the CDK app, or in a different region.
     * 
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param scope the parent Construct for this new Construct.
     * @param id the logical ID of this new Construct.
     * @param serverDeploymentConfigName the properties of the referenced custom Deployment Configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig fromServerDeploymentConfigName(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final java.lang.String serverDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "fromServerDeploymentConfigName", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(serverDeploymentConfigName, "serverDeploymentConfigName is required") });
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ALL_AT_ONCE;
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig HALF_AT_A_TIME;
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ONE_AT_A_TIME;

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDeploymentConfigArn() {
        return this.jsiiGet("deploymentConfigArn", java.lang.String.class);
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDeploymentConfigName() {
        return this.jsiiGet("deploymentConfigName", java.lang.String.class);
    }
}

==> codedeploy-1.6.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/codedeploy/ServerDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * A custom Deployment Configuration for an EC2/on-premise Deployment Group.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-27T17:36:11.089Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codedeploy.$Module.class, fqn = "@aws-cdk/aws-codedeploy.ServerDeploymentConfig")
public class ServerDeploymentConfig extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig {

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ServerDeploymentConfig(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    static {
        ALL_AT_ONCE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ALL_AT_ONCE", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        HALF_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "HALF_AT_A_TIME", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
        ONE_AT_A_TIME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "ONE_AT_A_TIME", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ServerDeploymentConfig(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.codedeploy.ServerDeploymentConfigProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     * Import a custom Deployment Configuration for an EC2/on-premise Deployment Group defined either outside the CDK app, or in a different region.
     * 
     * @return a Construct representing a reference to an existing custom Deployment Configuration
     * @param scope the parent Construct for this new Construct.
     * @param id the logical ID of this new Construct.
     * @param serverDeploymentConfigName the properties of the referenced custom Deployment Configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig fromServerDeploymentConfigName(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final java.lang.String serverDeploymentConfigName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codedeploy.ServerDeploymentConfig.class, "fromServerDeploymentConfigName", software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(serverDeploymentConfigName, "serverDeploymentConfigName is required") });
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ALL_AT_ONCE;
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig HALF_AT_A_TIME;
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.codedeploy.IServerDeploymentConfig ONE_AT_A_TIME;

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDeploymentConfigArn() {
        return this.jsiiGet("deploymentConfigArn", java.lang.String.class);
    }

    /**
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getDeploymentConfigName() {
        return this.jsiiGet("deploymentConfigName", java.lang.String.class);
    }
}
